@@ -1,6 +1,7 @@
 /*
- *  DBD::mSQL - DBI driver for the mysql database
+ *  DBD::mysql - DBI driver for the MySQL database
  *
+ *  Copyright (c) 2005       Patrick Galbraith
  *  Copyright (c) 2003       Rudolf Lippan
  *  Copyright (c) 1997-2003  Jochen Wiedmann
  *
@@ -11,7 +12,7 @@
  *  You may distribute this under the terms of either the GNU General Public
  *  License or the Artistic License, as specified in the Perl README file.
  *
- *  $Id: dbdimp.h 6304 2006-05-17 21:23:10Z capttofu $
+ *  $Id: dbdimp.h 6856 2006-09-06 00:23:13Z capttofu $
  */
 
 /*
@@ -143,6 +144,9 @@ struct imp_dbh_st {
                                */
     int use_server_side_prepare;
     int has_autodetect_prepare;
+#if defined(sv_utf8_decode) && MYSQL_VERSION_ID >=SERVER_PREPARE_VERSION
+    bool enable_utf8;
+#endif
 };
 
 
